@@ -6,21 +6,21 @@ import sys
 import time
 import argparse
 from typing import List
-from blessings import Terminal
-from colors import *
+from colors import color
 import pyfiglet
 import gitlab
 import yaml
-import os
 
-class facile_trigger_helper(object):
+
+class facile_trigger_helper:
     """
 
         :param args:
         :return: Args trasformed by the user
     """
 
-    def convert_args(self, args: List[str]):
+    @staticmethod
+    def convert_args(args: List[str]):
 
         """
 
@@ -48,7 +48,8 @@ class facile_trigger_helper(object):
 
         return parsed_args
 
-    def check_project(self, string_project, yaml_file):
+    @staticmethod
+    def check_project(string_project, yaml_file):
         """
 
         :project_id variable aims gitlab id found on project >> General:
@@ -59,19 +60,17 @@ class facile_trigger_helper(object):
             robot_path = ''
             for project_id, path in documents.items():
                 if str(project_id) in string_project.upper():
-                    robot_path = path               
+                    robot_path = path
 
             return robot_path
 
-
     def main(self, args: List[str]):
-       
+
         """
 
         :project_id variable aims gitlab id found on project >> General:
         """
         # Require parameters
-
         args = self.convert_args(args)
         assert args.gitlab_api_token, 'token should be set'
         assert args.project_id, 'project id must be set'
@@ -82,20 +81,21 @@ class facile_trigger_helper(object):
         project_id = args.project_id
         api_gilab_token = args.gitlab_api_token
         target_branch = args.target_branch
-        #ref_name = args.ref_name
+        # ref_name = args.ref_name
         print(args.ref_name)
         robot_path = self.check_project(args.ref_name, args.yaml_file)
 
         if robot_path:
-            
-            facile_trigger = pyfiglet.figlet_format("facile.it Trigger Helper", font = "larry3d"  ) 
-            print(color(facile_trigger, fg='orange'))
+            facile_trigger = pyfiglet.figlet_format("facile.it Trigger Helper", font="larry3d")
+            print(color(facile_trigger, fg='yellow'))
             print(color("Running robot path: " + robot_path, fg='green'))
-        
-            self.trigger_pipeline(robot_path, git_lab_host, 
-            api_gilab_token, target_branch, project_id)
 
-    def trigger_pipeline(self, ref_name, git_lab_host, api_gilab_token, target_branch, project_id):
+            facile_trigger_helper.trigger_pipeline(robot_path,
+                                                   git_lab_host, api_gilab_token,
+                                                   target_branch, project_id)
+
+    @staticmethod
+    def trigger_pipeline(ref_name, git_lab_host, api_gilab_token, target_branch, project_id):
         """
 
         :project_id variable aims gitlab id found on project >> General:
@@ -103,13 +103,14 @@ class facile_trigger_helper(object):
 
         git_trigger = gitlab.Gitlab(git_lab_host, private_token=api_gilab_token)
         project = git_trigger.projects.get(project_id)
-        create_pipeline = project.pipelines.create({'ref': target_branch , 'variables': [{'key': 'RF_PATH', 'value': ref_name }]})
-        
+        create_pipeline = project.pipelines.create(
+            {'ref': target_branch, 'variables': [{'key': 'RF_PATH', 'value': ref_name}]})
+
         pipeline = project.pipelines.get(create_pipeline.id)
         pipe_jobs = pipeline.jobs.list()
         pipeline_jobs_count = len(pipe_jobs)
         pipeline_jobs_count = str(pipeline_jobs_count)
-        print(color("Triggered pipeline holds " + pipeline_jobs_count + " jobs", fg='orange'))
+        print(color("Triggered pipeline holds " + pipeline_jobs_count + " jobs", fg='yellow'))
         timeout = time.time() + 60 * 30
 
         while pipeline.finished_at is None:
@@ -134,17 +135,18 @@ class facile_trigger_helper(object):
 
             time.sleep(2)
 
-def run_cli(arguments=None, exit=True):
-       
+
+def run_cli(arguments=None):
     """
 
     :project_id variable aims gitlab id found on project >> General:
     """
     if arguments is None:
         arguments = sys.argv[1:]
-    
+
     return facile_trigger_helper().main(arguments)
-            
+
+
 if __name__ == '__main__':
     run_cli(sys.argv[1:])
-    sys.exit(0)
\ No newline at end of file
+    sys.exit(0)
